pub enum InvalidLengthError {
_Fixed(usize, usize),
UpTo(usize, usize),
}Expand description
An error denoting that a value was of an invalid length. Typically this will be used as a
variant of ArxKwError rather than on its own.
Variants
_Fixed(usize, usize)
Invalid length in a context expecting a fixed length.
UpTo(usize, usize)
Invalid length in a context which accepts a variable length (e.g. plaintext and ciphertext inputs)